@@ -4,6 +4,6 @@ from . import game_query
 from . import game_record
 from . import season_manage
 from . import season_query
-from . import season_user_point_logs_export
+from . import season_user_point_export
 from . import season_user_point_manage
 from . import season_user_point_query
